==> hexo-theme-solitude-1.1.3.tgz: package/README_EN.md <==
<div align="right">
  Language:
  English / 
  <a title="English" href="/README.md">中文</a>
</div>

<p align="center"><img width="400" src="/source/img/logo-horizontal_version.png"></p>

<p align="center">An elegant Hexo theme</p>
<p align="center">"Explore the inner self in peaceful solitude, leading a life of simplicity and elegance."</p>

<p align="center">
  <a title="Hexo Version" target="_blank" href="https://hexo.io/zh-cn/"><img alt="Hexo Version" src="https://img.shields.io/badge/Hexo-%3E%3D%205.3.0-orange?style=flat"></a>
  <a title="Node Version" target="_blank" href="https://nodejs.org/zh-cn/"><img alt="Node Version" src="https://img.shields.io/badge/Node-%3E%3D%2010.13.0-yellowgreen?style=flat"></a>
  <a title="npm Downloads" target="_blank" href="https://www.npmjs.com/package/hexo-theme-solitude"><img alt="GitHub Forks" src="https://img.shields.io/npm/dt/hexo-theme-solitude?color=red&label=npm"></a>
  <a title="License" target="_blank" href="https://github.com/DuoSco/Hexo-theme-solitude/blob/main/LICENSE"><img alt="License" src="https://img.shields.io/github/license/DuoSco/Hexo-Theme-solitude.svg?style=flat"></a>
  <a title="GitHub Release" target="_blank" href="https://github.com/DuoSco/Hexo-theme-solitude/releases"><img alt="GitHub Release" src="https://img.shields.io/github/v/release/DuoSco/Hexo-theme-solitude?style=flat"></a>
  <a title="GitHub Commits" target="_blank" href="https://github.com/DuoSco/Hexo-Theme-solitude/commits/master"><img alt="GitHub Commits" src="https://img.shields.io/github/commit-activity/m/DuoSco/Hexo-Theme-solitude.svg?style=flat&color=brightgreen&label=commits"></a>
</p>

![](/source/img/solitude-show.jpg)

Theme Preview: 👋[Demo](https://solitude.wzsco.top/) | [王卓Sco](https://blog.wzsco.top/)

Theme Document: [📖Solidude Document](https://docs.wzsco.top/)

Theme discussion group：`The usage document above contains a QR code`

## 💻 Installation

### Installation via Git

Install the stable version in the root of your blog directory 【Recommended】

```powershell
git clone -b main https://github.com/DuoSco/Hexo-theme-solitude.git themes/solitude
```

If you want to install the latest development version, you can install the dev branch in the root of your blog directory

```powershell
git clone -b dev https://github.com/DuoSco/Hexo-theme-solitude.git themes/solitude
```

### Installation via npm

> This method only supports Hexo versions above 5.0.0. Installing through npm will not generate a theme folder in themes, but in node_modules instead.

Execute the following command in the root of your blog directory:

```powershell
npm install hexo-theme-solitude
```

## ⚙ Applying the Theme

Modify the hexo configuration file `_config.yml` and change the theme to `solitude`

```
theme: solitude
```

## 🛠️ Better Configuration

- MacOS/Linux Run the following command in the root of your blog directory

```bash
cp -rf ./themes/solitude/_config.yml ./_config.solitude.yml
```

- Windows Copy the file `/themes/solitude/_config.yml` to the root directory of your Hexo installation and rename it as `_config.solitude.yml`

## 🎁 Sponsor Us

As we generate power for Love, the domain name and some scattered expenses are borne by the developers. If possible, we hope to receive your appreciation. Thank you very much! 🙏 Of course, even without sponsorship, we will strive to continue developing.

[王卓Sco](https://afdian.net/a/wleelw0u0) &nbsp;  [亦小封](https://afdian.net/a/yife68)

## ✨ Contributors

<a href="https://github.com/DuoSco/Hexo-theme-solitude/graphs/contributors">
  <img src="https://contrib.rocks/image?repo=DuoSco/Hexo-theme-solitude" />
</a>

Special thanks to：
[@王卓Sco](https://github.com/wleelw)
[@亦小封](https://github.com/yife68)
[@rootlex](https://github.com/rootlexme)
[@timigomen](https://github.com/timigomen)
[@Glannons](https://github.com/Glannons)
[@Adil](https://github.com/adil-zhang)

**This theme is a derivative theme of [Heo](https://blog.zhheo.com/), designed and authorized by the author [张洪Heo](https://github.com/zhheo)!**

> Welcome to contribute to this theme!  [Contribution Guide](https://opensource.guide/zh-hans/how-to-contribute/#%E5%A6%82%E4%BD%95%E6%8F%90%E4%BA%A4%E8%B4%A1%E7%8C%AE)

## 📊 Repository Statistics
![Repository Statistics](https://repobeats.axiom.co/api/embed/75ec216f1d0b289e1b6a92f585342f3eeeeb0fdd.svg "Repobeats analytics image")

==> hexo-theme-solitude-1.3.1.tgz: package/README_EN.md <==
<div align="right">
  Language:
  English / 
  <a title="English" href="/README.md">中文</a>
</div>

<p align="center"><img width="400" src="https://bu.dusays.com/2023/12/20/6582bf58c64cf.png"></p>

<p align="center">An elegant Hexo theme</p>
<p align="center">"Explore the inner self in peaceful solitude, leading a life of simplicity and elegance."</p>

<p align="center">
  <a title="Hexo Version" target="_blank" href="https://hexo.io/zh-cn/"><img alt="Hexo Version" src="https://img.shields.io/badge/Hexo-%3E%3D%205.3.0-orange?style=flat"></a>
  <a title="Node Version" target="_blank" href="https://nodejs.org/zh-cn/"><img alt="Node Version" src="https://img.shields.io/badge/Node-%3E%3D%2010.13.0-yellowgreen?style=flat"></a>
  <a title="npm Downloads" target="_blank" href="https://www.npmjs.com/package/hexo-theme-solitude"><img alt="GitHub Forks" src="https://img.shields.io/npm/dt/hexo-theme-solitude?color=red&label=npm"></a>
  <a title="License" target="_blank" href="https://github.com/DuoSco/Hexo-theme-solitude/blob/main/LICENSE"><img alt="License" src="https://img.shields.io/github/license/DuoSco/Hexo-Theme-solitude.svg?style=flat"></a>
  <a title="GitHub Release" target="_blank" href="https://github.com/DuoSco/Hexo-theme-solitude/releases"><img alt="GitHub Release" src="https://img.shields.io/github/v/release/DuoSco/Hexo-theme-solitude?style=flat"></a>
  <a title="GitHub Commits" target="_blank" href="https://github.com/DuoSco/Hexo-Theme-solitude/commits/master"><img alt="GitHub Commits" src="https://img.shields.io/github/commit-activity/m/DuoSco/Hexo-Theme-solitude.svg?style=flat&color=brightgreen&label=commits"></a>
</p>

![](https://bu.dusays.com/2023/12/20/6582bf81b4641.png)

Theme Preview: 👋 [王卓Sco](https://blog.wzsco.top/) ｜ 🎆 [糕小菜](https://blog.kaixed.com/)

Theme Document: [📖 Solidude Document](https://docs.wzsco.top/)

Theme discussion group：`The usage document above contains a QR code`

## 💻 Installation

### Installation via Git

Install the stable version in the root of your blog directory 【Recommended】

```powershell
git clone -b main https://github.com/DuoSco/Hexo-theme-solitude.git themes/solitude
```

If you want to install the latest development version, you can install the dev branch in the root of your blog directory

```powershell
git clone -b dev https://github.com/DuoSco/Hexo-theme-solitude.git themes/solitude
```

### Installation via npm

> This method only supports Hexo versions above 5.0.0. Installing through npm will not generate a theme folder in themes, but in node_modules instead.

Execute the following command in the root of your blog directory:

```powershell
npm install hexo-theme-solitude
```

## ⚙ Applying the Theme

Modify the hexo configuration file `_config.yml` and change the theme to `solitude`

```
theme: solitude
```

## 🛠️ Better Configuration

- MacOS/Linux Run the following command in the root of your blog directory

```bash
cp -rf ./themes/solitude/_config.yml ./_config.solitude.yml
```

- Windows Copy the file `/themes/solitude/_config.yml` to the root directory of your Hexo installation and rename it as `_config.solitude.yml`

## 🎁 Sponsor Us

As we generate power for Love, the domain name and some scattered expenses are borne by the developers. If possible, we hope to receive your appreciation. Thank you very much! 🙏 Of course, even without sponsorship, we will strive to continue developing.

[@王卓Sco](https://afdian.net/a/wleelw0u0) &nbsp;  [@亦小封](https://afdian.net/a/yife68)

## ✨ Contributors

<a href="https://github.com/DuoSco/Hexo-theme-solitude/graphs/contributors">
  <img src="https://contrib.rocks/image?repo=DuoSco/Hexo-theme-solitude" />
</a>

Special thanks to：
[@王卓Sco](https://github.com/wleelw)
[@亦小封](https://github.com/yife68)
[@rootlex](https://github.com/rootlexme)
[@timigomen](https://github.com/timigomen)
[@Glannons](https://github.com/Glannons)
[@Adil](https://github.com/adil-zhang)

**This theme is a derivative theme of [Heo](https://blog.zhheo.com/), designed and authorized by the author [张洪Heo](https://github.com/zhheo)!**

> Welcome to contribute to this theme!  [Contribution Guide](/CONTRIBUTING.md)

## 📊 Repository Statistics
![Repository Statistics](https://repobeats.axiom.co/api/embed/75ec216f1d0b289e1b6a92f585342f3eeeeb0fdd.svg "Repobeats analytics image")
